pub enum ModalInteractionComponent {
Show 13 variants
ActionRow(ModalInteractionActionRow),
ChannelSelect(ModalInteractionChannelSelect),
Checkbox(ModalInteractionCheckbox),
CheckboxGroup(ModalInteractionCheckboxGroup),
FileUpload(ModalInteractionFileUpload),
Label(ModalInteractionLabel),
MentionableSelect(ModalInteractionMentionableSelect),
RoleSelect(ModalInteractionRoleSelect),
StringSelect(ModalInteractionStringSelect),
TextDisplay(ModalInteractionTextDisplay),
TextInput(ModalInteractionTextInput),
Unknown(u8),
UserSelect(ModalInteractionUserSelect),
}Expand description
User filled in modal component.
Variants
ActionRow(ModalInteractionActionRow)
Top-level layout component. In modals, layout components are preferred over action rows.
ChannelSelect(ModalInteractionChannelSelect)
Dropdown selection component for channels.
Checkbox(ModalInteractionCheckbox)
Checkbox Component
CheckboxGroup(ModalInteractionCheckboxGroup)
Checkbox Group Component.
FileUpload(ModalInteractionFileUpload)
File upload component.
Label(ModalInteractionLabel)
Top-level layout component including a string label and optional description.
MentionableSelect(ModalInteractionMentionableSelect)
Dropdown selection component for mentionables.
RoleSelect(ModalInteractionRoleSelect)
Dropdown selection component for roles.
StringSelect(ModalInteractionStringSelect)
Dropdown selection component for text.
TextDisplay(ModalInteractionTextDisplay)
Markdown text.
TextInput(ModalInteractionTextInput)
Text input component.
Unknown(u8)
Variant value is unknown to the library in the context of modals.
UserSelect(ModalInteractionUserSelect)
Dropdown selection component for users.
Implementations
Sourceimpl ModalInteractionComponent
impl ModalInteractionComponent
Sourcepub fn kind(&self) -> ComponentType
pub fn kind(&self) -> ComponentType
Type of component that this is.